<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/paquet-mots?lang_cible=lb
// ** ne pas modifier le fichier **

return [

	// M
	'mots_description' => 'Schlësselwierder a Gruppen',
	'mots_slogan' => 'Gestioun vun de Schlësselwierder a Gruppen am SPIP',
];
